==> yst-fin-api-1.3.23-zyyy-20251206.072911-2-sources.jar: com/elitesland/fin/dto/payorder/PayOrderRpcDTO.java <==
package com.elitesland.fin.dto.payorder;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.List;

/**
 * @author zhiyu.he
 * @date 2022/3/16 10:36
 */
@Data
public class PayOrderRpcDTO implements Serializable {
    @Serial
    private static final long serialVersionUID = -3556084242260987258L;

    @ApiModelProperty("来源系统单号")
    private String sourceNo;

    @ApiModelProperty(value = "公司编码")
    private String ouCode;
    @ApiModelProperty(value = "公司ID")
    private Long ouId;
    @ApiModelProperty(value = "公司名称")
    private String ouName;

    @ApiModelProperty(value = "部门ID")
    private Long buId;
    @ApiModelProperty(value = "部门编码")
    private String buCode;
    @ApiModelProperty(value = "部门名称")
    private String buName;

    @ApiModelProperty(value = "供应商ID")
    private Long suppId;
    @ApiModelProperty(value = "供应商编码")
    private String suppCode;
    @ApiModelProperty(value = "供应商名称")
    private String suppName;

    @ApiModelProperty(value = "经办人ID")
    private Long operUserId;
    @ApiModelProperty(value = "经办人")
    private String operator;

    @ApiModelProperty(value = "应付单类型定义ID")
    private Long apTypeId;
    @ApiModelProperty(value = "应付单类型")
    private String apTypeCode;
    @ApiModelProperty(value = "应付单类型名称")
    private String apTypeName;

    @ApiModelProperty(value = "付款单类型ID")
    private Long payTypeId;
    @ApiModelProperty(value = "付款单类型代码")
    private String payTypeCode;
    @ApiModelProperty(value = "付款单类型名称")
    private String payTypeName;

    @ApiModelProperty(value = "币种编码")
    private String currCode;
    @ApiModelProperty(value = "币种")
    private String currName;

    @ApiModelProperty(value = "单据来源", notes = "[UDC]yst-fin:PAY_DOC_CLS")
    private String createMode;

    @ApiModelProperty(value = "业务日期")
    private LocalDateTime buDate;

    @ApiModelProperty(value = "是否期初")
    private Boolean initFlag;

    @ApiModelProperty(value = "含税总金额")
    private BigDecimal totalAmt;
    @ApiModelProperty(value = "含税总金额(本位币)")
    private BigDecimal totalCurAmt;

    @ApiModelProperty(value = "预计付款日期")
    private LocalDateTime apDate;

    @ApiModelProperty(value = "是否预付")
    private Boolean apFlag;

    @ApiModelProperty(value = "本位币")
    private String localCurrCode;
    @ApiModelProperty(value = "本位币名称")
    private String localCurrName;

    @ApiModelProperty(value = "汇率")
    private BigDecimal exchangeRate;

    @ApiModelProperty(value = "付款方式", notes = "[UDC]yst-supp:PAY_METHOD")
    private String payType;
    @ApiModelProperty(value = "付款方开户银行")
    private String payBank;
    @ApiModelProperty(value = "付款方银行账户")
    private String payAccount;
    @ApiModelProperty(value = "收款方开户银行")
    private String recBank;
    @ApiModelProperty(value = "收款方银行账户")
    private String recAccount;

    @ApiModelProperty("明细集合")
    private List<PayOrderDtlRpcDTO> payOrderDtlVOList;
}

==> yst-fin-api-1.3.29-zyyy-20251208.103920-2-sources.jar: com/elitesland/fin/dto/payorder/PayOrderRpcDTO.java <==
package com.elitesland.fin.dto.payorder;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.List;

/**
 * @author zhiyu.he
 * @date 2022/3/16 10:36
 */
@Data
public class PayOrderRpcDTO implements Serializable {
    @Serial
    private static final long serialVersionUID = -3556084242260987258L;

    @ApiModelProperty(value = "付款单ID")
    private Long id;
    @ApiModelProperty(value = "付款单号")
    private String payOrderNo;

    @ApiModelProperty("来源系统单号")
    private String sourceNo;

    @ApiModelProperty(value = "公司编码")
    private String ouCode;
    @ApiModelProperty(value = "公司ID")
    private Long ouId;
    @ApiModelProperty(value = "公司名称")
    private String ouName;

    @ApiModelProperty(value = "部门ID")
    private Long buId;
    @ApiModelProperty(value = "部门编码")
    private String buCode;
    @ApiModelProperty(value = "部门名称")
    private String buName;

    @ApiModelProperty(value = "供应商ID")
    private Long suppId;
    @ApiModelProperty(value = "供应商编码")
    private String suppCode;
    @ApiModelProperty(value = "供应商名称")
    private String suppName;

    @ApiModelProperty(value = "经办人ID")
    private Long operUserId;
    @ApiModelProperty(value = "经办人")
    private String operator;

    @ApiModelProperty(value = "应付单类型定义ID")
    private Long apTypeId;
    @ApiModelProperty(value = "应付单类型")
    private String apTypeCode;
    @ApiModelProperty(value = "应付单类型名称")
    private String apTypeName;

    @ApiModelProperty(value = "付款单类型ID")
    private Long payTypeId;
    @ApiModelProperty(value = "付款单类型代码")
    private String payTypeCode;
    @ApiModelProperty(value = "付款单类型名称")
    private String payTypeName;

    @ApiModelProperty(value = "币种编码")
    private String currCode;
    @ApiModelProperty(value = "币种")
    private String currName;

    @ApiModelProperty(value = "单据来源", notes = "[UDC]yst-fin:PAY_DOC_CLS")
    private String createMode;

    @ApiModelProperty(value = "业务日期")
    private LocalDateTime buDate;

    @ApiModelProperty(value = "是否期初")
    private Boolean initFlag;

    @ApiModelProperty(value = "含税总金额")
    private BigDecimal totalAmt;
    @ApiModelProperty(value = "含税总金额(本位币)")
    private BigDecimal totalCurAmt;

    @ApiModelProperty(value = "预计付款日期")
    private LocalDateTime apDate;

    @ApiModelProperty(value = "是否预付")
    private Boolean apFlag;

    @ApiModelProperty(value = "本位币")
    private String localCurrCode;
    @ApiModelProperty(value = "本位币名称")
    private String localCurrName;

    @ApiModelProperty(value = "汇率")
    private BigDecimal exchangeRate;

    @ApiModelProperty(value = "付款方式", notes = "[UDC]yst-supp:PAY_METHOD")
    private String payType;
    @ApiModelProperty(value = "付款方开户银行")
    private String payBank;
    @ApiModelProperty(value = "付款方银行账户")
    private String payAccount;
    @ApiModelProperty(value = "收款方开户银行")
    private String recBank;
    @ApiModelProperty(value = "收款方银行账户")
    private String recAccount;

    @ApiModelProperty("明细集合")
    private List<PayOrderDtlRpcDTO> payOrderDtlVOList;
}
